# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: links/v1/links.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'links/v1/links.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14links/v1/links.proto\x12\x08links.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x03\n\x04Link\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0f\n\x07ios_url\x18\x05 \x01(\t\x12\x13\n\x0b\x61ndroid_url\x18\x06 \x01(\t\x12\x0f\n\x07web_url\x18\x07 \x01(\t\x12\x14\n\x0c\x66\x61llback_url\x18\x08 \x01(\t\x12\x12\n\nhuawei_url\x18\t \x01(\t\x12\x12\n\namazon_url\x18\n \x01(\t\x12\x13\n\x0bwindows_url\x18\x0b \x01(\t\x12\x11\n\tmacos_url\x18\x0c \x01(\t\x12\x10\n\x08\x61pp_name\x18\r \x01(\t\x12\x14\n\x0c\x61pp_icon_url\x18\x0e \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0f \x01(\t\x12\x11\n\tis_active\x18\x10 \x01(\x08\x12\x14\n\x0ctotal_clicks\x18\x11 \x01(\x03\x12.\n\ncreated_at\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"2\n\x10ListLinksRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x10\n\x08per_page\x18\x02 \x01(\x05\"a\n\x11ListLinksResponse\x12\x1d\n\x05links\x18\x01 \x03(\x0b\x32\x0e.links.v1.Link\x12\r\n\x05total\x18\x02 \x01(\x05\x12\x0c\n\x04page\x18\x03 \x01(\x05\x12\x10\n\x08per_page\x18\x04 \x01(\x05\"\x8a\x02\n\x11\x43reateLinkRequest\x12\x0c\n\x04slug\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07ios_url\x18\x03 \x01(\t\x12\x13\n\x0b\x61ndroid_url\x18\x04 \x01(\t\x12\x0f\n\x07web_url\x18\x05 \x01(\t\x12\x14\n\x0c\x66\x61llback_url\x18\x06 \x01(\t\x12\x12\n\nhuawei_url\x18\x07 \x01(\t\x12\x12\n\namazon_url\x18\x08 \x01(\t\x12\x13\n\x0bwindows_url\x18\t \x01(\t\x12\x11\n\tmacos_url\x18\n \x01(\t\x12\x10\n\x08\x61pp_name\x18\x0b \x01(\t\x12\x14\n\x0c\x61pp_icon_url\x18\x0c \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\r \x01(\t\"\x1c\n\x0eGetLinkRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x99\x02\n\x11UpdateLinkRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04slug\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05title\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07ios_url\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x61ndroid_url\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x14\n\x07web_url\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0c\x66\x61llback_url\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tis_active\x18\x08 \x01(\x08H\x06\x88\x01\x01\x42\x07\n\x05_slugB\x08\n\x06_titleB\n\n\x08_ios_urlB\x0e\n\x0c_android_urlB\n\n\x08_web_urlB\x0f\n\r_fallback_urlB\x0c\n\n_is_active\"\x1f\n\x11\x44\x65leteLinkRequest\x12\n\n\x02id\x18\x01 \x01(\t\"6\n\x12\x44\x65leteLinkResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\" \n\x10\x43heckSlugRequest\x12\x0c\n\x04slug\x18\x01 \x01(\t\"4\n\x11\x43heckSlugResponse\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x0c\n\x04slug\x18\x02 \x01(\t2\x8d\x03\n\x0bLinkService\x12\x44\n\tListLinks\x12\x1a.links.v1.ListLinksRequest\x1a\x1b.links.v1.ListLinksResponse\x12\x39\n\nCreateLink\x12\x1b.links.v1.CreateLinkRequest\x1a\x0e.links.v1.Link\x12\x33\n\x07GetLink\x12\x18.links.v1.GetLinkRequest\x1a\x0e.links.v1.Link\x12\x39\n\nUpdateLink\x12\x1b.links.v1.UpdateLinkRequest\x1a\x0e.links.v1.Link\x12G\n\nDeleteLink\x12\x1b.links.v1.DeleteLinkRequest\x1a\x1c.links.v1.DeleteLinkResponse\x12\x44\n\tCheckSlug\x12\x1a.links.v1.CheckSlugRequest\x1a\x1b.links.v1.CheckSlugResponseB1Z/github.com/gosms-ge/go2-sdk/go/links/v1;linksv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'links.v1.links_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/gosms-ge/go2-sdk/go/links/v1;linksv1'
  _globals['_LINK']._serialized_start=68
  _globals['_LINK']._serialized_end=487
  _globals['_LISTLINKSREQUEST']._serialized_start=489
  _globals['_LISTLINKSREQUEST']._serialized_end=539
  _globals['_LISTLINKSRESPONSE']._serialized_start=541
  _globals['_LISTLINKSRESPONSE']._serialized_end=638
  _globals['_CREATELINKREQUEST']._serialized_start=641
  _globals['_CREATELINKREQUEST']._serialized_end=907
  _globals['_GETLINKREQUEST']._serialized_start=909
  _globals['_GETLINKREQUEST']._serialized_end=937
  _globals['_UPDATELINKREQUEST']._serialized_start=940
  _globals['_UPDATELINKREQUEST']._serialized_end=1221
  _globals['_DELETELINKREQUEST']._serialized_start=1223
  _globals['_DELETELINKREQUEST']._serialized_end=1254
  _globals['_DELETELINKRESPONSE']._serialized_start=1256
  _globals['_DELETELINKRESPONSE']._serialized_end=1310
  _globals['_CHECKSLUGREQUEST']._serialized_start=1312
  _globals['_CHECKSLUGREQUEST']._serialized_end=1344
  _globals['_CHECKSLUGRESPONSE']._serialized_start=1346
  _globals['_CHECKSLUGRESPONSE']._serialized_end=1398
  _globals['_LINKSERVICE']._serialized_start=1401
  _globals['_LINKSERVICE']._serialized_end=1798
# @@protoc_insertion_point(module_scope)
