# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qr/v1/qr.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'qr/v1/qr.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eqr/v1/qr.proto\x12\x05qr.v1\"\x88\x01\n\x11GenerateQRRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\x12\x18\n\x10\x66oreground_color\x18\x04 \x01(\t\x12\x18\n\x10\x62\x61\x63kground_color\x18\x05 \x01(\t\x12\x10\n\x08logo_url\x18\x06 \x01(\t\"?\n\x12GenerateQRResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t2N\n\tQRService\x12\x41\n\nGenerateQR\x12\x18.qr.v1.GenerateQRRequest\x1a\x19.qr.v1.GenerateQRResponseB+Z)github.com/gosms-ge/go2-sdk/go/qr/v1;qrv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qr.v1.qr_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/gosms-ge/go2-sdk/go/qr/v1;qrv1'
  _globals['_GENERATEQRREQUEST']._serialized_start=26
  _globals['_GENERATEQRREQUEST']._serialized_end=162
  _globals['_GENERATEQRRESPONSE']._serialized_start=164
  _globals['_GENERATEQRRESPONSE']._serialized_end=227
  _globals['_QRSERVICE']._serialized_start=229
  _globals['_QRSERVICE']._serialized_end=307
# @@protoc_insertion_point(module_scope)
