# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: analytics/v1/analytics.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'analytics/v1/analytics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61nalytics/v1/analytics.proto\x12\x0c\x61nalytics.v1\"2\n\x0fGetStatsRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\"\xfc\x01\n\x10GetStatsResponse\x12\x14\n\x0ctotal_clicks\x18\x01 \x01(\x03\x12\x15\n\runique_clicks\x18\x02 \x01(\x03\x12\x12\n\nios_clicks\x18\x03 \x01(\x03\x12\x16\n\x0e\x61ndroid_clicks\x18\x04 \x01(\x03\x12\x12\n\nweb_clicks\x18\x05 \x01(\x03\x12\x14\n\x0cother_clicks\x18\x06 \x01(\x03\x12\x31\n\rtop_countries\x18\x07 \x03(\x0b\x32\x1a.analytics.v1.CountryStats\x12\x32\n\rtop_referrers\x18\x08 \x03(\x0b\x32\x1b.analytics.v1.ReferrerStats\"7\n\x14GetTimeseriesRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\"F\n\x15GetTimeseriesResponse\x12-\n\x06points\x18\x01 \x03(\x0b\x32\x1d.analytics.v1.TimeseriesPoint\"F\n\x0fTimeseriesPoint\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x0e\n\x06\x63licks\x18\x02 \x01(\x03\x12\x15\n\runique_clicks\x18\x03 \x01(\x03\"6\n\x13GetPlatformsRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\"F\n\x14GetPlatformsResponse\x12.\n\tplatforms\x18\x01 \x03(\x0b\x32\x1b.analytics.v1.PlatformStats\"E\n\rPlatformStats\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\x0e\n\x06\x63licks\x18\x02 \x01(\x03\x12\x12\n\npercentage\x18\x03 \x01(\x01\"E\n\x13GetCountriesRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\"E\n\x14GetCountriesResponse\x12-\n\tcountries\x18\x01 \x03(\x0b\x32\x1a.analytics.v1.CountryStats\"^\n\x0c\x43ountryStats\x12\x14\n\x0c\x63ountry_code\x18\x01 \x01(\t\x12\x14\n\x0c\x63ountry_name\x18\x02 \x01(\t\x12\x0e\n\x06\x63licks\x18\x03 \x01(\x03\x12\x12\n\npercentage\x18\x04 \x01(\x01\"E\n\x13GetReferrersRequest\x12\x0f\n\x07link_id\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\"F\n\x14GetReferrersResponse\x12.\n\treferrers\x18\x01 \x03(\x0b\x32\x1b.analytics.v1.ReferrerStats\"E\n\rReferrerStats\x12\x10\n\x08referrer\x18\x01 \x01(\t\x12\x0e\n\x06\x63licks\x18\x02 \x01(\x03\x12\x12\n\npercentage\x18\x03 \x01(\x01\x32\xbc\x03\n\x10\x41nalyticsService\x12I\n\x08GetStats\x12\x1d.analytics.v1.GetStatsRequest\x1a\x1e.analytics.v1.GetStatsResponse\x12X\n\rGetTimeseries\x12\".analytics.v1.GetTimeseriesRequest\x1a#.analytics.v1.GetTimeseriesResponse\x12U\n\x0cGetPlatforms\x12!.analytics.v1.GetPlatformsRequest\x1a\".analytics.v1.GetPlatformsResponse\x12U\n\x0cGetCountries\x12!.analytics.v1.GetCountriesRequest\x1a\".analytics.v1.GetCountriesResponse\x12U\n\x0cGetReferrers\x12!.analytics.v1.GetReferrersRequest\x1a\".analytics.v1.GetReferrersResponseB9Z7github.com/gosms-ge/go2-sdk/go/analytics/v1;analyticsv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analytics.v1.analytics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/gosms-ge/go2-sdk/go/analytics/v1;analyticsv1'
  _globals['_GETSTATSREQUEST']._serialized_start=46
  _globals['_GETSTATSREQUEST']._serialized_end=96
  _globals['_GETSTATSRESPONSE']._serialized_start=99
  _globals['_GETSTATSRESPONSE']._serialized_end=351
  _globals['_GETTIMESERIESREQUEST']._serialized_start=353
  _globals['_GETTIMESERIESREQUEST']._serialized_end=408
  _globals['_GETTIMESERIESRESPONSE']._serialized_start=410
  _globals['_GETTIMESERIESRESPONSE']._serialized_end=480
  _globals['_TIMESERIESPOINT']._serialized_start=482
  _globals['_TIMESERIESPOINT']._serialized_end=552
  _globals['_GETPLATFORMSREQUEST']._serialized_start=554
  _globals['_GETPLATFORMSREQUEST']._serialized_end=608
  _globals['_GETPLATFORMSRESPONSE']._serialized_start=610
  _globals['_GETPLATFORMSRESPONSE']._serialized_end=680
  _globals['_PLATFORMSTATS']._serialized_start=682
  _globals['_PLATFORMSTATS']._serialized_end=751
  _globals['_GETCOUNTRIESREQUEST']._serialized_start=753
  _globals['_GETCOUNTRIESREQUEST']._serialized_end=822
  _globals['_GETCOUNTRIESRESPONSE']._serialized_start=824
  _globals['_GETCOUNTRIESRESPONSE']._serialized_end=893
  _globals['_COUNTRYSTATS']._serialized_start=895
  _globals['_COUNTRYSTATS']._serialized_end=989
  _globals['_GETREFERRERSREQUEST']._serialized_start=991
  _globals['_GETREFERRERSREQUEST']._serialized_end=1060
  _globals['_GETREFERRERSRESPONSE']._serialized_start=1062
  _globals['_GETREFERRERSRESPONSE']._serialized_end=1132
  _globals['_REFERRERSTATS']._serialized_start=1134
  _globals['_REFERRERSTATS']._serialized_end=1203
  _globals['_ANALYTICSSERVICE']._serialized_start=1206
  _globals['_ANALYTICSSERVICE']._serialized_end=1650
# @@protoc_insertion_point(module_scope)
