# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: integrations/v1/integrations.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'integrations/v1/integrations.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"integrations/v1/integrations.proto\x12\x0fintegrations.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x88\x03\n\x0bIntegration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12.\n\x04type\x18\x03 \x01(\x0e\x32 .integrations.v1.IntegrationType\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x32\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\".integrations.v1.IntegrationConfig\x12\x0e\n\x06\x65vents\x18\x06 \x03(\t\x12\x11\n\tis_active\x18\x07 \x01(\x08\x12:\n\x11last_triggered_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x15\n\rtrigger_count\x18\t \x01(\x05\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x14\n\x12_last_triggered_at\"p\n\x11IntegrationConfig\x12\x13\n\x0bwebhook_url\x18\x01 \x01(\t\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\t\x12\x11\n\tbot_token\x18\x03 \x01(\t\x12\x0f\n\x07\x63hat_id\x18\x04 \x01(\t\x12\x11\n\twrite_key\x18\x05 \x01(\t\"\x19\n\x17ListIntegrationsRequest\"N\n\x18ListIntegrationsResponse\x12\x32\n\x0cintegrations\x18\x01 \x03(\x0b\x32\x1c.integrations.v1.Integration\"\x9c\x01\n\x18\x43reateIntegrationRequest\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .integrations.v1.IntegrationType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x32\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\".integrations.v1.IntegrationConfig\x12\x0e\n\x06\x65vents\x18\x04 \x03(\t\"#\n\x15GetIntegrationRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\xbc\x01\n\x18UpdateIntegrationRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x37\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\".integrations.v1.IntegrationConfigH\x01\x88\x01\x01\x12\x0e\n\x06\x65vents\x18\x04 \x03(\t\x12\x16\n\tis_active\x18\x05 \x01(\x08H\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_configB\x0c\n\n_is_active\"&\n\x18\x44\x65leteIntegrationRequest\x12\n\n\x02id\x18\x01 \x01(\t\",\n\x19\x44\x65leteIntegrationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"$\n\x16TestIntegrationRequest\x12\n\n\x02id\x18\x01 \x01(\t\";\n\x17TestIntegrationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x1c\n\x1aGetIntegrationTypesRequest\"b\n\x1bGetIntegrationTypesResponse\x12\x33\n\x05types\x18\x01 \x03(\x0b\x32$.integrations.v1.IntegrationTypeInfo\x12\x0e\n\x06\x65vents\x18\x02 \x03(\t\"\xbe\x01\n\x13IntegrationTypeInfo\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .integrations.v1.IntegrationType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x11\n\tavailable\x18\x05 \x01(\x08\x12\x33\n\rconfig_fields\x18\x06 \x03(\x0b\x32\x1c.integrations.v1.ConfigField\"x\n\x0b\x43onfigField\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x12\n\nfield_type\x18\x03 \x01(\t\x12\x10\n\x08required\x18\x04 \x01(\x08\x12\x13\n\x0bplaceholder\x18\x05 \x01(\t\x12\x11\n\thelp_text\x18\x06 \x01(\t*\xc7\x01\n\x0fIntegrationType\x12 \n\x1cINTEGRATION_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16INTEGRATION_TYPE_SLACK\x10\x01\x12\x1c\n\x18INTEGRATION_TYPE_DISCORD\x10\x02\x12\x1d\n\x19INTEGRATION_TYPE_TELEGRAM\x10\x03\x12\x1c\n\x18INTEGRATION_TYPE_SEGMENT\x10\x04\x12\x1b\n\x17INTEGRATION_TYPE_ZAPIER\x10\x05\x32\xd5\x05\n\x12IntegrationService\x12g\n\x10ListIntegrations\x12(.integrations.v1.ListIntegrationsRequest\x1a).integrations.v1.ListIntegrationsResponse\x12\\\n\x11\x43reateIntegration\x12).integrations.v1.CreateIntegrationRequest\x1a\x1c.integrations.v1.Integration\x12V\n\x0eGetIntegration\x12&.integrations.v1.GetIntegrationRequest\x1a\x1c.integrations.v1.Integration\x12\\\n\x11UpdateIntegration\x12).integrations.v1.UpdateIntegrationRequest\x1a\x1c.integrations.v1.Integration\x12j\n\x11\x44\x65leteIntegration\x12).integrations.v1.DeleteIntegrationRequest\x1a*.integrations.v1.DeleteIntegrationResponse\x12\x64\n\x0fTestIntegration\x12\'.integrations.v1.TestIntegrationRequest\x1a(.integrations.v1.TestIntegrationResponse\x12p\n\x13GetIntegrationTypes\x12+.integrations.v1.GetIntegrationTypesRequest\x1a,.integrations.v1.GetIntegrationTypesResponseBCZAgithub.com/go2-link/backend/pkg/pb/integrations/v1;integrationsv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'integrations.v1.integrations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/go2-link/backend/pkg/pb/integrations/v1;integrationsv1'
  _globals['_INTEGRATIONTYPE']._serialized_start=1722
  _globals['_INTEGRATIONTYPE']._serialized_end=1921
  _globals['_INTEGRATION']._serialized_start=89
  _globals['_INTEGRATION']._serialized_end=481
  _globals['_INTEGRATIONCONFIG']._serialized_start=483
  _globals['_INTEGRATIONCONFIG']._serialized_end=595
  _globals['_LISTINTEGRATIONSREQUEST']._serialized_start=597
  _globals['_LISTINTEGRATIONSREQUEST']._serialized_end=622
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_start=624
  _globals['_LISTINTEGRATIONSRESPONSE']._serialized_end=702
  _globals['_CREATEINTEGRATIONREQUEST']._serialized_start=705
  _globals['_CREATEINTEGRATIONREQUEST']._serialized_end=861
  _globals['_GETINTEGRATIONREQUEST']._serialized_start=863
  _globals['_GETINTEGRATIONREQUEST']._serialized_end=898
  _globals['_UPDATEINTEGRATIONREQUEST']._serialized_start=901
  _globals['_UPDATEINTEGRATIONREQUEST']._serialized_end=1089
  _globals['_DELETEINTEGRATIONREQUEST']._serialized_start=1091
  _globals['_DELETEINTEGRATIONREQUEST']._serialized_end=1129
  _globals['_DELETEINTEGRATIONRESPONSE']._serialized_start=1131
  _globals['_DELETEINTEGRATIONRESPONSE']._serialized_end=1175
  _globals['_TESTINTEGRATIONREQUEST']._serialized_start=1177
  _globals['_TESTINTEGRATIONREQUEST']._serialized_end=1213
  _globals['_TESTINTEGRATIONRESPONSE']._serialized_start=1215
  _globals['_TESTINTEGRATIONRESPONSE']._serialized_end=1274
  _globals['_GETINTEGRATIONTYPESREQUEST']._serialized_start=1276
  _globals['_GETINTEGRATIONTYPESREQUEST']._serialized_end=1304
  _globals['_GETINTEGRATIONTYPESRESPONSE']._serialized_start=1306
  _globals['_GETINTEGRATIONTYPESRESPONSE']._serialized_end=1404
  _globals['_INTEGRATIONTYPEINFO']._serialized_start=1407
  _globals['_INTEGRATIONTYPEINFO']._serialized_end=1597
  _globals['_CONFIGFIELD']._serialized_start=1599
  _globals['_CONFIGFIELD']._serialized_end=1719
  _globals['_INTEGRATIONSERVICE']._serialized_start=1924
  _globals['_INTEGRATIONSERVICE']._serialized_end=2649
# @@protoc_insertion_point(module_scope)
