# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: domains/v1/domains.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'domains/v1/domains.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x64omains/v1/domains.proto\x12\ndomains.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xec\x02\n\x06\x44omain\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0e\n\x06\x64omain\x18\x03 \x01(\t\x12(\n\x06status\x18\x04 \x01(\x0e\x32\x18.domains.v1.DomainStatus\x12\x1a\n\x12verification_token\x18\x05 \x01(\t\x12\x34\n\x0bverified_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12)\n\nssl_status\x18\x07 \x01(\x0e\x32\x15.domains.v1.SSLStatus\x12\x1e\n\x16\x63loudflare_hostname_id\x18\x08 \x01(\t\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0e\n\x0c_verified_at\"6\n\tDNSRecord\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x14\n\x12ListDomainsRequest\":\n\x13ListDomainsResponse\x12#\n\x07\x64omains\x18\x01 \x03(\x0b\x32\x12.domains.v1.Domain\"%\n\x13\x43reateDomainRequest\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\"f\n\x14\x43reateDomainResponse\x12\"\n\x06\x64omain\x18\x01 \x01(\x0b\x32\x12.domains.v1.Domain\x12*\n\x0b\x64ns_records\x18\x02 \x03(\x0b\x32\x15.domains.v1.DNSRecord\"\x1e\n\x10GetDomainRequest\x12\n\n\x02id\x18\x01 \x01(\t\"!\n\x13VerifyDomainRequest\x12\n\n\x02id\x18\x01 \x01(\t\"!\n\x13\x44\x65leteDomainRequest\x12\n\n\x02id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteDomainResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t*\x99\x01\n\x0c\x44omainStatus\x12\x1d\n\x19\x44OMAIN_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x44OMAIN_STATUS_PENDING\x10\x01\x12\x1b\n\x17\x44OMAIN_STATUS_VERIFYING\x10\x02\x12\x18\n\x14\x44OMAIN_STATUS_ACTIVE\x10\x03\x12\x18\n\x14\x44OMAIN_STATUS_FAILED\x10\x04*\x8a\x01\n\tSSLStatus\x12\x1a\n\x16SSL_STATUS_UNSPECIFIED\x10\x00\x12\x16\n\x12SSL_STATUS_PENDING\x10\x01\x12\x1b\n\x17SSL_STATUS_PROVISIONING\x10\x02\x12\x15\n\x11SSL_STATUS_ACTIVE\x10\x03\x12\x15\n\x11SSL_STATUS_FAILED\x10\x04\x32\x89\x03\n\rDomainService\x12N\n\x0bListDomains\x12\x1e.domains.v1.ListDomainsRequest\x1a\x1f.domains.v1.ListDomainsResponse\x12Q\n\x0c\x43reateDomain\x12\x1f.domains.v1.CreateDomainRequest\x1a .domains.v1.CreateDomainResponse\x12=\n\tGetDomain\x12\x1c.domains.v1.GetDomainRequest\x1a\x12.domains.v1.Domain\x12\x43\n\x0cVerifyDomain\x12\x1f.domains.v1.VerifyDomainRequest\x1a\x12.domains.v1.Domain\x12Q\n\x0c\x44\x65leteDomain\x12\x1f.domains.v1.DeleteDomainRequest\x1a .domains.v1.DeleteDomainResponseB5Z3github.com/gosms-ge/go2-sdk/go/domains/v1;domainsv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'domains.v1.domains_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/gosms-ge/go2-sdk/go/domains/v1;domainsv1'
  _globals['_DOMAINSTATUS']._serialized_start=882
  _globals['_DOMAINSTATUS']._serialized_end=1035
  _globals['_SSLSTATUS']._serialized_start=1038
  _globals['_SSLSTATUS']._serialized_end=1176
  _globals['_DOMAIN']._serialized_start=74
  _globals['_DOMAIN']._serialized_end=438
  _globals['_DNSRECORD']._serialized_start=440
  _globals['_DNSRECORD']._serialized_end=494
  _globals['_LISTDOMAINSREQUEST']._serialized_start=496
  _globals['_LISTDOMAINSREQUEST']._serialized_end=516
  _globals['_LISTDOMAINSRESPONSE']._serialized_start=518
  _globals['_LISTDOMAINSRESPONSE']._serialized_end=576
  _globals['_CREATEDOMAINREQUEST']._serialized_start=578
  _globals['_CREATEDOMAINREQUEST']._serialized_end=615
  _globals['_CREATEDOMAINRESPONSE']._serialized_start=617
  _globals['_CREATEDOMAINRESPONSE']._serialized_end=719
  _globals['_GETDOMAINREQUEST']._serialized_start=721
  _globals['_GETDOMAINREQUEST']._serialized_end=751
  _globals['_VERIFYDOMAINREQUEST']._serialized_start=753
  _globals['_VERIFYDOMAINREQUEST']._serialized_end=786
  _globals['_DELETEDOMAINREQUEST']._serialized_start=788
  _globals['_DELETEDOMAINREQUEST']._serialized_end=821
  _globals['_DELETEDOMAINRESPONSE']._serialized_start=823
  _globals['_DELETEDOMAINRESPONSE']._serialized_end=879
  _globals['_DOMAINSERVICE']._serialized_start=1179
  _globals['_DOMAINSERVICE']._serialized_end=1572
# @@protoc_insertion_point(module_scope)
