# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: campaigns/v1/campaigns.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'campaigns/v1/campaigns.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63\x61mpaigns/v1/campaigns.proto\x12\x0c\x63\x61mpaigns.v1\"\xaf\x02\n\x08\x43\x61mpaign\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x17\n\x0f\x64\x65stination_url\x18\x05 \x01(\t\x12\x19\n\x11pass_recipient_id\x18\x06 \x01(\x08\x12\x1c\n\x14recipient_param_name\x18\x07 \x01(\t\x12\x18\n\x10total_recipients\x18\x08 \x01(\x05\x12\x14\n\x0ctotal_clicks\x18\t \x01(\x03\x12\x15\n\runique_clicks\x18\n \x01(\x05\x12\x0e\n\x06status\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x0c \x01(\t\x12\x12\n\nupdated_at\x18\r \x01(\t\x12\x12\n\nexpires_at\x18\x0e \x01(\t\"\xc9\x03\n\x0c\x43\x61mpaignLink\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x14\n\x0crecipient_id\x18\x04 \x01(\t\x12\x16\n\x0erecipient_name\x18\x05 \x01(\t\x12M\n\x12recipient_metadata\x18\x06 \x03(\x0b\x32\x31.campaigns.v1.CampaignLink.RecipientMetadataEntry\x12\x0f\n\x07\x63licked\x18\x07 \x01(\x08\x12\x18\n\x10\x66irst_clicked_at\x18\x08 \x01(\t\x12\x17\n\x0flast_clicked_at\x18\t \x01(\t\x12\x13\n\x0b\x63lick_count\x18\n \x01(\x05\x12\x1c\n\x14\x66irst_click_platform\x18\x0b \x01(\t\x12\x1b\n\x13\x66irst_click_country\x18\x0c \x01(\t\x12\x18\n\x10\x66irst_click_city\x18\r \x01(\t\x12\x12\n\ncreated_at\x18\x0e \x01(\t\x12\x11\n\tshort_url\x18\x0f \x01(\t\x1a\x38\n\x16RecipientMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n\tRecipient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x37\n\x08metadata\x18\x03 \x03(\x0b\x32%.campaigns.v1.Recipient.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x14ListCampaignsRequest\x12\r\n\x05limit\x18\x01 \x01(\x05\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x0e\n\x06search\x18\x04 \x01(\t\"Q\n\x15ListCampaignsResponse\x12)\n\tcampaigns\x18\x01 \x03(\x0b\x32\x16.campaigns.v1.Campaign\x12\r\n\x05total\x18\x02 \x01(\x05\"\xa0\x01\n\x15\x43reateCampaignRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65stination_url\x18\x03 \x01(\t\x12\x19\n\x11pass_recipient_id\x18\x04 \x01(\x08\x12\x1c\n\x14recipient_param_name\x18\x05 \x01(\t\x12\x12\n\nexpires_at\x18\x06 \x01(\t\" \n\x12GetCampaignRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\xbc\x01\n\x15UpdateCampaignRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65stination_url\x18\x04 \x01(\t\x12\x19\n\x11pass_recipient_id\x18\x05 \x01(\x08\x12\x1c\n\x14recipient_param_name\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\t\x12\x12\n\nexpires_at\x18\x08 \x01(\t\"#\n\x15\x44\x65leteCampaignRequest\x12\n\n\x02id\x18\x01 \x01(\t\")\n\x16\x44\x65leteCampaignResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"X\n\x14GenerateLinksRequest\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12+\n\nrecipients\x18\x02 \x03(\x0b\x32\x17.campaigns.v1.Recipient\"u\n\x15GenerateLinksResponse\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x15\n\rlinks_created\x18\x02 \x01(\x05\x12\x30\n\x0csample_links\x18\x03 \x03(\x0b\x32\x1a.campaigns.v1.CampaignLink\"t\n\x18ListCampaignLinksRequest\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x14\n\x0c\x63licked_only\x18\x04 \x01(\x08\x12\x0e\n\x06search\x18\x05 \x01(\t\"U\n\x19ListCampaignLinksResponse\x12)\n\x05links\x18\x01 \x03(\x0b\x32\x1a.campaigns.v1.CampaignLink\x12\r\n\x05total\x18\x02 \x01(\x05\".\n\x17GetCampaignStatsRequest\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\"\x85\x04\n\rCampaignStats\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x18\n\x10total_recipients\x18\x02 \x01(\x05\x12\x14\n\x0ctotal_clicks\x18\x03 \x01(\x03\x12\x15\n\runique_clicks\x18\x04 \x01(\x05\x12\x12\n\nclick_rate\x18\x05 \x01(\x01\x12M\n\x12\x63licks_by_platform\x18\x06 \x03(\x0b\x32\x31.campaigns.v1.CampaignStats.ClicksByPlatformEntry\x12K\n\x11\x63licks_by_country\x18\x07 \x03(\x0b\x32\x30.campaigns.v1.CampaignStats.ClicksByCountryEntry\x12\x43\n\rclicks_by_day\x18\x08 \x03(\x0b\x32,.campaigns.v1.CampaignStats.ClicksByDayEntry\x1a\x37\n\x15\x43licksByPlatformEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x36\n\x14\x43licksByCountryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x32\n\x10\x43licksByDayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"9\n\x12\x45xportLinksRequest\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\"@\n\x13\x45xportLinksResponse\x12)\n\x05links\x18\x01 \x03(\x0b\x32\x1a.campaigns.v1.CampaignLink2\x9b\x06\n\x0f\x43\x61mpaignService\x12X\n\rListCampaigns\x12\".campaigns.v1.ListCampaignsRequest\x1a#.campaigns.v1.ListCampaignsResponse\x12M\n\x0e\x43reateCampaign\x12#.campaigns.v1.CreateCampaignRequest\x1a\x16.campaigns.v1.Campaign\x12G\n\x0bGetCampaign\x12 .campaigns.v1.GetCampaignRequest\x1a\x16.campaigns.v1.Campaign\x12M\n\x0eUpdateCampaign\x12#.campaigns.v1.UpdateCampaignRequest\x1a\x16.campaigns.v1.Campaign\x12[\n\x0e\x44\x65leteCampaign\x12#.campaigns.v1.DeleteCampaignRequest\x1a$.campaigns.v1.DeleteCampaignResponse\x12X\n\rGenerateLinks\x12\".campaigns.v1.GenerateLinksRequest\x1a#.campaigns.v1.GenerateLinksResponse\x12\x64\n\x11ListCampaignLinks\x12&.campaigns.v1.ListCampaignLinksRequest\x1a\'.campaigns.v1.ListCampaignLinksResponse\x12V\n\x10GetCampaignStats\x12%.campaigns.v1.GetCampaignStatsRequest\x1a\x1b.campaigns.v1.CampaignStats\x12R\n\x0b\x45xportLinks\x12 .campaigns.v1.ExportLinksRequest\x1a!.campaigns.v1.ExportLinksResponseB9Z7github.com/gosms-ge/go2-sdk/go/campaigns/v1;campaignsv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'campaigns.v1.campaigns_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/gosms-ge/go2-sdk/go/campaigns/v1;campaignsv1'
  _globals['_CAMPAIGNLINK_RECIPIENTMETADATAENTRY']._loaded_options = None
  _globals['_CAMPAIGNLINK_RECIPIENTMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_RECIPIENT_METADATAENTRY']._loaded_options = None
  _globals['_RECIPIENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CAMPAIGNSTATS_CLICKSBYPLATFORMENTRY']._loaded_options = None
  _globals['_CAMPAIGNSTATS_CLICKSBYPLATFORMENTRY']._serialized_options = b'8\001'
  _globals['_CAMPAIGNSTATS_CLICKSBYCOUNTRYENTRY']._loaded_options = None
  _globals['_CAMPAIGNSTATS_CLICKSBYCOUNTRYENTRY']._serialized_options = b'8\001'
  _globals['_CAMPAIGNSTATS_CLICKSBYDAYENTRY']._loaded_options = None
  _globals['_CAMPAIGNSTATS_CLICKSBYDAYENTRY']._serialized_options = b'8\001'
  _globals['_CAMPAIGN']._serialized_start=47
  _globals['_CAMPAIGN']._serialized_end=350
  _globals['_CAMPAIGNLINK']._serialized_start=353
  _globals['_CAMPAIGNLINK']._serialized_end=810
  _globals['_CAMPAIGNLINK_RECIPIENTMETADATAENTRY']._serialized_start=754
  _globals['_CAMPAIGNLINK_RECIPIENTMETADATAENTRY']._serialized_end=810
  _globals['_RECIPIENT']._serialized_start=813
  _globals['_RECIPIENT']._serialized_end=956
  _globals['_RECIPIENT_METADATAENTRY']._serialized_start=909
  _globals['_RECIPIENT_METADATAENTRY']._serialized_end=956
  _globals['_LISTCAMPAIGNSREQUEST']._serialized_start=958
  _globals['_LISTCAMPAIGNSREQUEST']._serialized_end=1043
  _globals['_LISTCAMPAIGNSRESPONSE']._serialized_start=1045
  _globals['_LISTCAMPAIGNSRESPONSE']._serialized_end=1126
  _globals['_CREATECAMPAIGNREQUEST']._serialized_start=1129
  _globals['_CREATECAMPAIGNREQUEST']._serialized_end=1289
  _globals['_GETCAMPAIGNREQUEST']._serialized_start=1291
  _globals['_GETCAMPAIGNREQUEST']._serialized_end=1323
  _globals['_UPDATECAMPAIGNREQUEST']._serialized_start=1326
  _globals['_UPDATECAMPAIGNREQUEST']._serialized_end=1514
  _globals['_DELETECAMPAIGNREQUEST']._serialized_start=1516
  _globals['_DELETECAMPAIGNREQUEST']._serialized_end=1551
  _globals['_DELETECAMPAIGNRESPONSE']._serialized_start=1553
  _globals['_DELETECAMPAIGNRESPONSE']._serialized_end=1594
  _globals['_GENERATELINKSREQUEST']._serialized_start=1596
  _globals['_GENERATELINKSREQUEST']._serialized_end=1684
  _globals['_GENERATELINKSRESPONSE']._serialized_start=1686
  _globals['_GENERATELINKSRESPONSE']._serialized_end=1803
  _globals['_LISTCAMPAIGNLINKSREQUEST']._serialized_start=1805
  _globals['_LISTCAMPAIGNLINKSREQUEST']._serialized_end=1921
  _globals['_LISTCAMPAIGNLINKSRESPONSE']._serialized_start=1923
  _globals['_LISTCAMPAIGNLINKSRESPONSE']._serialized_end=2008
  _globals['_GETCAMPAIGNSTATSREQUEST']._serialized_start=2010
  _globals['_GETCAMPAIGNSTATSREQUEST']._serialized_end=2056
  _globals['_CAMPAIGNSTATS']._serialized_start=2059
  _globals['_CAMPAIGNSTATS']._serialized_end=2576
  _globals['_CAMPAIGNSTATS_CLICKSBYPLATFORMENTRY']._serialized_start=2413
  _globals['_CAMPAIGNSTATS_CLICKSBYPLATFORMENTRY']._serialized_end=2468
  _globals['_CAMPAIGNSTATS_CLICKSBYCOUNTRYENTRY']._serialized_start=2470
  _globals['_CAMPAIGNSTATS_CLICKSBYCOUNTRYENTRY']._serialized_end=2524
  _globals['_CAMPAIGNSTATS_CLICKSBYDAYENTRY']._serialized_start=2526
  _globals['_CAMPAIGNSTATS_CLICKSBYDAYENTRY']._serialized_end=2576
  _globals['_EXPORTLINKSREQUEST']._serialized_start=2578
  _globals['_EXPORTLINKSREQUEST']._serialized_end=2635
  _globals['_EXPORTLINKSRESPONSE']._serialized_start=2637
  _globals['_EXPORTLINKSRESPONSE']._serialized_end=2701
  _globals['_CAMPAIGNSERVICE']._serialized_start=2704
  _globals['_CAMPAIGNSERVICE']._serialized_end=3499
# @@protoc_insertion_point(module_scope)
